<?php
/**
* @package RSSeo!
* @copyright (C) 2015 www.rsjoomla.com
* @license GPL, http://www.gnu.org/copyleft/gpl.html
*/
defined('_JEXEC') or die('Restricted access');

class rsseoModelKeyword extends JModelAdmin
{
	/**
	 * @var		string	The prefix to use with controller messages.
	 * @since	1.6
	 */
	protected $text_prefix = 'COM_RSSEO';

	
	/**
	 * Returns a Table object, always creating it.
	 *
	 * @param	type	The table type to instantiate
	 * @param	string	A prefix for the table class name. Optional.
	 * @param	array	Configuration array for model. Optional.
	 *
	 * @return	JTable	A database object
	*/
	public function getTable($type = 'Keyword', $prefix = 'rsseoTable', $config = array()) {
		return JTable::getInstance($type, $prefix, $config);
	}
	
	/**
	 * Method to get a single record.
	 *
	 * @param	integer	The id of the primary key.
	 *
	 * @return	mixed	Object on success, false on failure.
	 */
	public function getItem($pk = null) {
		$item = parent::getItem($pk);
		
		return $item;
	}
	
	/**
	 * Method to get the record form.
	 *
	 * @param	array	$data		Data for the form.
	 * @param	boolean	$loadData	True if the form is to load its own data (default case), false if not.
	 *
	 * @return	mixed	A JForm object on success, false on failure
	 * @since	1.6
	 */
	public function getForm($data = array(), $loadData = true) {		
		// Get the form.
		$form = $this->loadForm('com_rsseo.keyword', 'keyword', array('control' => 'jform', 'load_data' => $loadData));
		if (empty($form))
			return false;
		
		return $form;
	}
	
	/**
	 * Method to get the data that should be injected in the form.
	 *
	 * @return	mixed	The data for the form.
	 * @since	1.6
	 */
	protected function loadFormData() {
		// Check the session for previously entered form data.
		$data = JFactory::getApplication()->getUserState('com_rsseo.edit.keyword.data', array());

		if (empty($data))
			$data = $this->getItem();
			
		return $data;
	}
	
	public function save($data) {
		// Initialise variables;
		$table = $this->getTable();
		$pk = (!empty($data['id'])) ? $data['id'] : (int) $this->getState($this->getName() . '.id');
		$isNew = true;

		// Load the row if saving an existing tag.
		if ($pk > 0) {
			$table->load($pk);
			$isNew = false;
		}

		// Bind the data.
		if (!$table->bind($data)) {
			$this->setError($table->getError());
			return false;
		}

		// Check the data.
		if (!$table->check()) {
			$this->setError($table->getError());
			return false;
		}

		// Store the data.
		if (!$table->store()) {
			$this->setError($table->getError());
			return false;
		}
		
		if ($isNew) {
			require_once JPATH_ADMINISTRATOR. '/components/com_rsseo/helpers/keywords.php';
			$keyword = keywordsHelper::getInstance($table->id, $table->keyword);
			$keyword->check();
		}
		
		$this->setState($this->getName() . '.id', $table->id);
		
		return true;
	}
	
	public function statistics() {
		$db		= JFactory::getDbo();
		$query	= $db->getQuery(true);
		$id		= JFactory::getApplication()->input->getInt('id',0);
		$return	= array();
		
		$query->clear()
			->select('MAX('.$db->qn('p.position').') AS position')->select('DATE_FORMAT(DATE('.$db->qn('p.date').'),"%M %Y") AS thedate')
			->select('DATE('.$db->qn('p.date').') AS data')
			->from($db->qn('#__rsseo_keyword_position','p'))
			->join('LEFT',$db->qn('#__rsseo_keywords','k').' ON '.$db->qn('k.id').' = '.$db->qn('p.idk'))
			->where($db->qn('k.id').' = '.$db->q($id))
			->group('thedate')
			->group($db->qn('p.idk'))
			->order('data ASC');
		
		$db->setQuery($query);
		if ($data = $db->loadObjectList()) {
			$return[] = array(JText::_('COM_RSSEO_STATISTICS_DATE'),JText::_('COM_RSSEO_STATISTICS_POSITION'));
			foreach ($data as $keyword) {
				$return[] = array($keyword->thedate, (int) $keyword->position);
			}
		}
		
		return $return;
	}
}